/* Jacek Cichon */
/* Wroclaw 2018 */

var canvas;
var info1;
var info2;
var ctx;
var myTimer;
var width;
var height;
var stars = [];

function Particle(x,y, vx, vy, mass) {
  this.x = x;
  this.y = y;
  this.vx = vx;
  this.vy = vy;
  this.mass = mass;
}

function gravitate(partA, partB) {
  var dx = partB.x - partA.x;
  var dy = partB.y - partA.y;
  var distSQ = dx * dx + dy * dy;
  var dist   = Math.sqrt(distSQ);
  var force  = partA.mass * partB.mass / distSQ;
  var ax = force * dx / dist;
  var ay = force * dy / dist;
  partA.vx += ax / partA.mass;
  partA.vy += ay / partA.mass;
  partB.vx -= ax / partB.mass;
  partB.vy -= ay / partB.mass;
  partA.x += partA.vx;
  partA.y += partA.vy;
  partB.x += partB.vx;
  partB.y += partB.vy;
}

function myRandomInteger(a, b) {
  return Math.floor(Math.random()*(b-a+1)+a);
}

function initAll() {
  canvas = document.getElementById("canvas");
  info1  = document.getElementById("info1");
  info2  = document.getElementById("info2");
  ctx    = canvas.getContext("2d");
  width  = canvas.width;
  height = width * (6.0 / 8.0);
  ctx.canvas.height = height;

  var i; 
  for (i = 0; i < 50; i+= 1) {
    let x = myRandomInteger(2, width - 4);
    let y = myRandomInteger(2, width - 4);
    stars.push([x, y]);
  }

  rocket  = new Particle(10,  height*(1/3), 0.1, 0, 0.1);
  sun     = new Particle(width-10,  height/2, -0.1, 0, 10);
  myTimer = setInterval(draw, 50);
}

function draw() {
  ctx.fillStyle = "#000";
  ctx.fillRect(0, 0, width, height);
  var i;
  for (i = 0; i < stars.length; i+= 1) {
    ctx.beginPath();
    ctx.fillStyle = "#fff";
    ctx.arc(stars[i][0],stars[i][1], 2, 0, 2*Math.PI, false);
    ctx.closePath();
    ctx.fill();
  }

  ctx.beginPath();
  ctx.fillStyle = "red";
  ctx.arc(rocket.x,rocket.y, 5,0, 2*Math.PI,false);
  ctx.closePath();
  ctx.fill();

  ctx.beginPath();
  ctx.fillStyle = "rgb(255,255,0)";
  ctx.arc(sun.x, sun.y, 10,0, 2*Math.PI,false);

  ctx.closePath();
  ctx.fill();
  
  gravitate(rocket,sun);
  var x = rocket.vx;
  var y = rocket.vy;
  info1.innerHTML = Math.sqrt(x*x+y*y).toFixed(7);

  x = sun.vx;
  y = sun.vy;
  info2.innerHTML = Math.sqrt(x*x+y*y).toFixed(7);

  if ((rocket.x<0) || (rocket.y<0)) {
    clearInterval(myTimer);
  }
}